@@ -33,9 +33,16 @@ from servicecatalog_puppet.workflow.launch.reset_provisioned_product_owner_task
 from servicecatalog_puppet.workflow.spoke_local_portfolios import (
     spoke_local_portfolio_section_task,
 )
+from servicecatalog_puppet.workflow.service_control_policies import (
+    service_control_policies_section_task,
+)
+from servicecatalog_puppet.workflow.simulate_policies import (
+    simulate_policy_section_task,
+)
 from servicecatalog_puppet.workflow.stack import stack_section_task
 from servicecatalog_puppet.workflow.workspaces import workspace_section_task
 
+
 logger = logging.getLogger(constants.PUPPET_LOGGER_NAME)
 
 
@@ -306,6 +313,9 @@ def generate_tasks(
             code_build_run_section_task.CodeBuildRunsSectionTask(
                 manifest_file_path=f.name, puppet_account_id=puppet_account_id,
             ),
+            simulate_policy_section_task.SimulatePolicysSectionTask(
+                manifest_file_path=f.name, puppet_account_id=puppet_account_id,
+            ),
         ]
         if execution_mode != constants.EXECUTION_MODE_SPOKE:
             tasks.append(
@@ -313,6 +323,11 @@ def generate_tasks(
                     manifest_file_path=f.name, puppet_account_id=puppet_account_id,
                 )
             )
+            tasks.append(
+                service_control_policies_section_task.ServiceControlPoliciesSectionTask(
+                    manifest_file_path=f.name, puppet_account_id=puppet_account_id,
+                )
+            )
 
     return tasks
 
